@@ -4,7 +4,7 @@ LINK_FMT = "https://dagster.cloud/{organization_id}/{deployment_name}/instance/r
 
 
 class DagsterLink(BaseOperatorLink):
-    name = "Dagster Cloud"
+    name = "Dagster Cloud"  # type: ignore  # (airflow 1 compat)
 
     def get_link(self, operator, dttm):
         ti = TaskInstance(task=operator, execution_date=dttm)
